@@ -3,7 +3,7 @@
 import hashlib
 import os
 from datetime import UTC, datetime, timedelta
-from typing import Annotated, AsyncGenerator, List, Optional
+from typing import Annotated, AsyncGenerator, Optional
 from uuid import UUID, uuid4
 
 from fastapi import APIRouter, Depends, HTTPException, Request, status
@@ -96,8 +96,8 @@ class UserResponse(BaseModel):
     id: UUID
     email: str
     name: str
-    roles: List[str]
-    permissions: List[str]
+    roles: list[str]
+    permissions: list[str]
     is_active: bool
     email_verified: bool
     created_at: datetime
@@ -211,12 +211,12 @@ async def get_current_user(
         raise HTTPException(status_code=status.HTTP_401_UNAUTHORIZED, detail=str(e))
 
 
-@auth_router.post("/register", response_model=AuthResponse, status_code=status.HTTP_201_CREATED)
+@auth_router.post("/register", status_code=status.HTTP_201_CREATED)
 async def register(
     request: RegisterRequest,
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> AuthResponse:
     """Register a new user."""
     # Check if email already exists
     async with db.cursor() as cursor:
@@ -280,12 +280,12 @@ async def register(
     )
 
 
-@auth_router.post("/login", response_model=AuthResponse)
+@auth_router.post("/login")
 async def login(
     request: LoginRequest,
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> AuthResponse:
     """Login with email and password."""
     # Get user by email
     async with db.cursor() as cursor:
@@ -341,13 +341,13 @@ async def login(
     )
 
 
-@auth_router.post("/refresh", response_model=TokenResponse)
+@auth_router.post("/refresh")
 async def refresh_token(
     request: RefreshRequest,
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
     token_manager: Annotated[TokenManager, Depends(get_token_manager)],
-):
+) -> TokenResponse:
     """Refresh access token using refresh token."""
     try:
         # Verify the refresh token
@@ -404,8 +404,10 @@ async def refresh_token(
         raise HTTPException(status_code=status.HTTP_401_UNAUTHORIZED, detail=str(e))
 
 
-@auth_router.get("/me", response_model=UserResponse)
-async def get_current_user_info(current_user: Annotated[User, Depends(get_current_user)]):
+@auth_router.get("/me")
+async def get_current_user_info(
+    current_user: Annotated[User, Depends(get_current_user)],
+) -> UserResponse:
     """Get current user information."""
     return UserResponse(
         id=current_user.id,
@@ -420,14 +422,14 @@ async def get_current_user_info(current_user: Annotated[User, Depends(get_curren
     )
 
 
-@auth_router.post("/logout", response_model=MessageResponse)
+@auth_router.post("/logout")
 async def logout(
     request: LogoutRequest,
     current_user: Annotated[User, Depends(get_current_user)],
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
     token_manager: Annotated[TokenManager, Depends(get_token_manager)],
-):
+) -> MessageResponse:
     """Logout and invalidate refresh token."""
     # Invalidate the refresh token family
     try:
@@ -451,12 +453,12 @@ async def logout(
         return MessageResponse(message="Successfully logged out")
 
 
-@auth_router.post("/forgot-password", response_model=MessageResponse)
+@auth_router.post("/forgot-password")
 async def forgot_password(
     request: ForgotPasswordRequest,
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> MessageResponse:
     """Request password reset email."""
     # Always return success to prevent email enumeration
     async with db.cursor() as cursor:
@@ -484,12 +486,12 @@ async def forgot_password(
     return MessageResponse(message="If the email exists, a reset link has been sent")
 
 
-@auth_router.post("/reset-password", response_model=MessageResponse)
+@auth_router.post("/reset-password")
 async def reset_password(
     request: ResetPasswordRequest,
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> MessageResponse:
     """Reset password using reset token."""
     # Hash the incoming token to compare with stored hash
     token_hash = hashlib.sha256(request.token.encode()).hexdigest()
@@ -544,12 +546,12 @@ async def reset_password(
     return MessageResponse(message="Password reset successfully")
 
 
-@auth_router.get("/sessions", response_model=List[SessionResponse])
+@auth_router.get("/sessions")
 async def list_sessions(
     current_user: Annotated[User, Depends(get_current_user)],
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> list[SessionResponse]:
     """List all active sessions for current user."""
     async with db.cursor() as cursor:
         await cursor.execute(
@@ -580,13 +582,13 @@ async def list_sessions(
     ]
 
 
-@auth_router.delete("/sessions/{session_id}", response_model=MessageResponse)
+@auth_router.delete("/sessions/{session_id}")
 async def revoke_session(
     session_id: UUID,
     current_user: Annotated[User, Depends(get_current_user)],
     db: Annotated[AsyncConnection, Depends(get_db)],
     schema: Annotated[str, Depends(get_schema)],
-):
+) -> MessageResponse:
     """Revoke a specific session."""
     # Verify session belongs to user
     async with db.cursor() as cursor:
