@@ -4,7 +4,8 @@ from fraiseql.cli.commands.check import check
 from fraiseql.cli.commands.dev import dev
 from fraiseql.cli.commands.generate import generate
 from fraiseql.cli.commands.init import init as init_command
+from fraiseql.cli.commands.migrate import migrate
 from fraiseql.cli.commands.sql import sql
 from fraiseql.cli.commands.turbo import turbo
 
-__all__ = ["check", "dev", "generate", "init_command", "sql", "turbo"]
+__all__ = ["check", "dev", "generate", "init_command", "migrate", "sql", "turbo"]
