@@ -5,7 +5,7 @@ from __future__ import annotations
 import asyncio
 import logging
 from types import MappingProxyType
-from typing import TYPE_CHECKING, Any, cast, get_type_hints
+from typing import TYPE_CHECKING, Any, Callable, cast, get_type_hints
 
 from graphql import (
     GraphQLArgument,
@@ -140,8 +140,11 @@ class QueryTypeBuilder:
             )
 
     def _create_gql_resolver(
-        self, fn, arg_name_mapping: dict[str, str] | None = None, field_name: str | None = None
-    ):
+        self,
+        fn: Callable[..., Any],
+        arg_name_mapping: dict[str, str] | None = None,
+        field_name: str | None = None,
+    ) -> Callable[..., Any]:
         """Create a GraphQL resolver from a function.
 
         Args:
@@ -160,7 +163,9 @@ class QueryTypeBuilder:
 
         if asyncio.iscoroutinefunction(coerced_fn):
 
-            async def async_resolver(root, info, **kwargs):
+            async def async_resolver(
+                root: dict[str, Any], info: GraphQLResolveInfo, **kwargs: Any
+            ) -> Any:
                 # Store GraphQL info and field name in context for repository
                 if hasattr(info, "context"):
                     info.context["graphql_info"] = info
@@ -183,7 +188,7 @@ class QueryTypeBuilder:
 
             return async_resolver
 
-        def sync_resolver(root, info, **kwargs):
+        def sync_resolver(root: dict[str, Any], info: GraphQLResolveInfo, **kwargs: Any) -> Any:
             # Store GraphQL info and field name in context for repository
             if hasattr(info, "context"):
                 info.context["graphql_info"] = info
