@@ -11,7 +11,9 @@ https://github.com/apollographql/apollo-link-persisted-queries
 """
 
 import logging
-from typing import Any, Dict, Optional
+from typing import Any, Optional
+
+from graphql import GraphQLSchema
 
 from fraiseql.fastapi.routers import GraphQLRequest
 from fraiseql.storage.apq_store import get_persisted_query
@@ -87,7 +89,7 @@ def is_apq_with_query_request(request: GraphQLRequest) -> bool:
 
 def create_apq_error_response(
     error_code: str, message: str, details: Optional[str] = None
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Create standardized APQ error response.
 
     Args:
@@ -110,11 +112,11 @@ def create_apq_error_response(
 
 async def execute_persisted_query(
     query: str,
-    schema,
-    context_value: Optional[Dict[str, Any]] = None,
-    variables: Optional[Dict[str, Any]] = None,
+    schema: GraphQLSchema,
+    context_value: Optional[dict[str, Any]] = None,
+    variables: Optional[dict[str, Any]] = None,
     operation_name: Optional[str] = None,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Execute a persisted GraphQL query using FraiseQL's execution engine.
 
     Args:
@@ -155,9 +157,9 @@ async def execute_persisted_query(
 
 def handle_apq_request(
     hash_value: Optional[str],
-    variables: Optional[Dict[str, Any]],
+    variables: Optional[dict[str, Any]],
     operation_name: Optional[str] = None,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Handle APQ request and return GraphQL response.
 
     Args:
